@@ -106,7 +106,7 @@
     }
 
     if (duration > 0) {
-        VLCTime *time = [VLCTime timeWithNumber:[NSNumber numberWithLong:duration]];
+        VLCTime *time = [VLCTime timeWithNumber:[NSNumber numberWithLongLong:duration]];
         [subtitle appendString:[time verboseStringValue]];
     }
 
@@ -115,7 +115,7 @@
                                                       stringFromByteCount:_oneDriveFile.size
                                                       countStyle:NSByteCountFormatterCountStyleFile]];
         if (duration > 0) {
-            VLCTime *time = [VLCTime timeWithNumber:[NSNumber numberWithLong:duration]];
+            VLCTime *time = [VLCTime timeWithNumber:[NSNumber numberWithLongLong:duration]];
             [subtitle appendFormat:@" — %@", [time verboseStringValue]];
         }
     }
