@@ -23,15 +23,11 @@
 #import "HTTPDynamicFileResponse.h"
 #import "HTTPErrorResponse.h"
 #import "NSString+SupportedMedia.h"
-#import "UIDevice+VLC.h"
 #import "VLCHTTPUploaderController.h"
 #import "VLCMetaData.h"
 #import "GCDAsyncSocket.h"
-
-#if TARGET_OS_IOS
 #import "VLC-Swift.h"
-#import "VLCThumbnailsCache.h"
-#endif
+
 #if TARGET_OS_TV
 #import "VLCPlayerControlWebSocket.h"
 #endif
@@ -231,6 +227,10 @@ static NSMutableDictionary *authentifiedHosts;
             message = NSLocalizedString(@"WEBINTF_AUTH_BANNED", nil);
             remainingAttempts = @"";
             break;
+        default:
+            result = @"ko";
+            message = @"";
+            remainingAttempts = @"";
     }
     NSDictionary *returnData = @{
         @"result": result,
@@ -254,18 +254,13 @@ static NSMutableDictionary *authentifiedHosts;
     if (!filepath) return NO;
 
     NSError *error;
+    NSURLRelationship relationship;
 
     NSArray *searchPaths = NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES);
     NSString *directoryPath = [searchPaths firstObject];
 
-    NSArray *array = [[NSFileManager defaultManager] contentsOfDirectoryAtPath:directoryPath error:&error];
-
-    if (error != nil) {
-        APLog(@"checking filerelationship failed %@", error);
-        return NO;
-    }
-
-    return [array containsObject:filepath.lastPathComponent];
+    [[NSFileManager defaultManager] getRelationship:&relationship ofDirectoryAtURL:[NSURL fileURLWithPath:directoryPath] toItemAtURL:[NSURL fileURLWithPath:filepath] error:&error];
+    return relationship == NSURLRelationshipContains;
 }
 
 #if TARGET_OS_IOS
@@ -717,8 +712,12 @@ static NSMutableDictionary *authentifiedHosts;
 
     _receivedContent += postDataChunk.length;
 
+#if WIFI_SHARING_DEBUG || TARGET_OS_TV
     long long percentage = ((_receivedContent * 100) / _contentLength);
+#if WIFI_SHARING_DEBUG
     APLog(@"received %lli kB (%lli %%)", _receivedContent / 1024, percentage);
+#endif
+#endif
 #if TARGET_OS_TV
         if (percentage >= 10) {
             [self performSelectorOnMainThread:@selector(startPlaybackOfPath:) withObject:_filepath waitUntilDone:NO];
@@ -754,14 +753,6 @@ static NSMutableDictionary *authentifiedHosts;
     if (!vpc.mediaList) {
         [vpc playMediaList:mediaList firstIndex:0 subtitlesFilePath:nil];
     }
-
-    VLCFullscreenMovieTVViewController *movieVC = [VLCFullscreenMovieTVViewController fullscreenMovieTVViewController];
-
-    if (![movieVC isBeingPresented]) {
-        [[UIApplication sharedApplication].keyWindow.rootViewController presentViewController:movieVC
-                                                                                     animated:YES
-                                                                                   completion:nil];
-    }
 }
 #endif
 
